<?php

  class ticket_model extends MY_Model {

      function __construct() {
          parent::__construct();
          $this->load->database();

          $this->table_name = 'ticket';
          $this->class_name = 'ticket_model';
      }

      public function getOne($access_user_level, $id) {

          if ($access_user_level != null && is_array($access_user_level)) {
              $this->db->where_in($this->table_name . ".user_id", $access_user_level);
          } else {
              return array();
          }

          $this->db->select("ticket.*, customer.*, " . "ticket.id AS ticket_id, ticket.status AS ticket_status, ticket.user_id AS ticket_user_id, ticket.create_date AS ticket_create_date, ticket.update_date AS ticket_update_date");
          
          $this->db->where($this->table_name . ".id", $id);
          $this->db->join("customer AS customer", "customer.id=" . $this->table_name . ".customer_id", "left");

          $query = $this->db->get($this->table_name, 1, 0);

          $result = $query->row_array();
          return $result;
      }

      public function findList($keyword, $access_dept_level, $access_user_level, $status, $filter_list = null, $data_range = null, $limit = 20, $offset = 0, $arr_sort = null) {

          $table_name = $this->db->dbprefix . $this->table_name;
          if ($keyword) {
              $this->db->where("(" . $table_name . ".id LIKE '%" . $keyword . "%' OR " . $table_name . ".subject LIKE '%" . $keyword . "%' OR customer.first_name LIKE '%" . $keyword . "%' OR customer.email LIKE '%" . $keyword . "%')");
          }

          if ($access_dept_level != null && is_array($access_dept_level)) {
              $this->db->where_in($table_name . ".dept_id", $access_dept_level);
          } else {
              return array();
          }

          if ($access_user_level != null && is_array($access_user_level)) {
              $this->db->where_in($table_name . ".user_id", $access_user_level);
          } else {
              return array();
          }

          if ($status) {
              $this->db->where_in($table_name . ".status", $status);
          }

          if ($filter_list && is_array($filter_list)) {
              foreach ($filter_list as $key => $filter) {
                  if (trim($filter) != "") {
                      $this->db->where($table_name . "." . $key, $filter);
                  }
              }
          }

          if ($data_range) {
              $this->db->where("(" . $table_name . ".update_date > DATE_SUB('" . gmdate('Y-m-d H:i:s') . "', INTERVAL " . $data_range . " DAY))", NULL, FALSE);
          }

          if ($arr_sort != null && is_array($arr_sort)) {
              foreach ($arr_sort as $field => $order) {
                  $this->db->order_by($field, $order);
              }
          } else {
              $this->db->order_by($table_name . ".update_date", "DESC");
          }

          $this->db->select($table_name . ".*, customer.first_name AS first_name, customer.email AS email");

          $this->db->join("customer AS customer", "customer.id=" . $table_name . ".customer_id", "left");
          $query = $this->db->get($this->table_name, $limit, $offset);

          $result = $query->result_array();

          return $result;
      }

      public function listCount($keyword, $access_dept_level, $access_user_level, $status, $filter_list =null, $data_range = null) {
          $table_name = $this->db->dbprefix . $this->table_name;

          if ($keyword) {
              $this->db->where("(" . $table_name . ".id LIKE '%" . $keyword . "%' OR " . $table_name . ".subject LIKE '%" . $keyword . "%' OR customer.first_name LIKE '%" . $keyword . "%' OR customer.email LIKE '%" . $keyword . "%')");
          }

          if ($status) {
              $this->db->where_in($table_name . ".status", $status);
          }

          if ($access_dept_level != null && is_array($access_dept_level)) {
              $this->db->where_in($table_name . ".dept_id", $access_dept_level);
          } else {
              return array();
          }

          if ($access_user_level != null && is_array($access_user_level)) {
              $this->db->where_in($table_name . ".user_id", $access_user_level);
          } else {
              return array();
          }

          if ($filter_list && is_array($filter_list)) {
              foreach ($filter_list as $key => $filter) {
                  if (trim($filter) != "") {
                      $this->db->where($table_name . "." . $key, $filter);
                  }
              }
          }

          if ($data_range) {
              $this->db->where("(" . $table_name . ".update_date > DATE_SUB('" . gmdate('Y-m-d H:i:s') . "', INTERVAL " . $data_range . " DAY))", NULL, FALSE);
          }

          $this->db->select("COUNT(*) AS counts");
          $this->db->join("customer AS customer", "customer.id=ticket.customer_id", "left");
          $query = $this->db->get($this->table_name);
          $result = $query->row_array();

          return (int) $result["counts"];
      }

      public function unsignList($limit=20, $offset=0) {
          $this->db->where("(status <2 OR user_id =0)", null, FALSE);
          $this->db->where("removed", 0);

          $query = $this->db->get($this->table_name, $limit, $offset);
          $result = $query->result_array();

          return $result;
      }

      public function newCount($access_user_level = null, $data_range = null, $include_removed =false) {
          $this->db->where_in("status", array(2, 4));

          if ($access_user_level != null && is_array($access_user_level)) {
              $this->db->where_in("user_id", $access_user_level);
          } else {
              return array();
          }

          if ($data_range) {
              $this->db->where("(update_date > DATE_SUB('" . gmdate('Y-m-d H:i:s') . "', INTERVAL " . $data_range . " DAY))", NULL, FALSE);
          }

          if ($include_removed) {
              $this->db->where_in("removed", array("1", "0"));
          } else {
              $this->db->where("removed", 0);
          }

          $this->db->select("COUNT(*) AS counts");
          $query = $this->db->get($this->table_name);
          $result = $query->row_array();

          return (int) $result["counts"];
      }

      public function allByDay($date_from, $date_to) {
          $this->db->select('DATE(create_date) AS create_day, COUNT(id) AS counts');

          $this->db->where(array('DATE(create_date) >' => $date_from, 'DATE(create_date) <' => $date_to));

          $this->db->group_by('create_day');

          $query = $this->db->get($this->table_name);
          return $query->result_array();
      }

      public function allByMonth($month_from, $month_to) {
          $this->db->select('YEAR(create_date) AS create_year, MONTH(create_date) AS create_month, COUNT(id) AS counts');
          $this->db->where(array('DATE(create_date) >' => $month_from, 'DATE(create_date) <' => $month_to));

          $this->db->group_by(array('create_year', 'create_month'));

          $query = $this->db->get($this->table_name);
          return $query->result_array();
      }

      public function resolvedByDay($date_from, $date_to) {
          $this->db->select('DATE(create_date) AS create_date, COUNT(id) AS counts');

          $this->db->where(array('status' => 3, 'DATE(create_date) >' => $date_from, 'DATE(create_date) <' => $date_to));
          $this->db->group_by('create_date');

          $query = $this->db->get($this->table_name);
          return $query->result_array();
      }

      public function resolvedByMonth($month_from, $month_to) {
          $this->db->select('YEAR(create_date) AS create_year, MONTH(create_date) AS create_month, COUNT(id) AS counts');

          $this->db->where(array('status' => 3, 'DATE(create_date) >' => $month_from, 'DATE(create_date) <' => $month_to));
          $this->db->group_by(array('create_year', 'create_month'));

          $query = $this->db->get($this->table_name);
          return $query->result_array();
      }

      public function nonresponseList($idle_datetime) {
          $this->db->where("user_id > ", 0);
          $this->db->where("update_date < ", $idle_datetime);
          $this->db->where_in("status", "2,4");

          $query = $this->db->get($this->table_name);
          $result = $query->result_array();

          return $result;
      }

  }

?>